DigestChallenge

Struct DigestChallenge 

pub struct DigestChallenge { /* private fields */ }
Digest challenge.

Implementations

Source

impl DigestChallenge

pub fn builder<T>(realm: T) -> DigestChallengeBuilder
where T: Into<String>,

Get a Digest challenge builder for a given realm.

pub fn realm(&self) -> &str

Get the realm.

pub fn nonce(&self) -> &str

Get the nonce.

pub fn algorithm_param(&self) -> Option<&str>

Get the algorithm parameter as sent in the challenge.

pub fn algorithm(&self) -> DigestAlgorithm

Get the actual digest algorithm.

pub fn qops(&self) -> &[QualityOfProtection]

Get the quality of protection values.

pub fn opaque(&self) -> Option<&str>

Get the opaque parameter.

pub fn response_builder(&self) -> DigestResponseBuilder<'_>

Get a Digest response builder for this challenge.