pub struct DigestChallengeBuilder { /* private fields */ }Expand description
Digest challenge builder.
Implementations
Sourceimpl DigestChallengeBuilder
impl DigestChallengeBuilder
Sourcepub fn nonce<T>(self, nonce: T) -> Self
pub fn nonce<T>(self, nonce: T) -> Self
Set the nonce value.
If not set, a random nonce will be generated.
Sourcepub fn qops<I>(self, qops: I) -> Selfwhere
I: IntoIterator<Item = QualityOfProtection>,
pub fn qops<I>(self, qops: I) -> Selfwhere
I: IntoIterator<Item = QualityOfProtection>,
Set the quality of protection values.
If empty, no qop parameter will be included in the challenge. The default value is an empty list.
Sourcepub fn algorithm(self, algorithm: DigestAlgorithm) -> Self
pub fn algorithm(self, algorithm: DigestAlgorithm) -> Self
Set the digest algorithm.
The default value is MD5.
Sourcepub fn emit_md5(self, emit_md5: bool) -> Self
pub fn emit_md5(self, emit_md5: bool) -> Self
Set whether to emit the algorithm=MD5 parameter in the challenge.
The default value is true.
Sourcepub fn build(self) -> DigestChallenge
pub fn build(self) -> DigestChallenge
Build the Digest challenge.