DigestResponseBuilder

Struct DigestResponseBuilder 

pub struct DigestResponseBuilder<'a> { /* private fields */ }
Digest response builder.

Implementations

Source

impl DigestResponseBuilder<'_>

pub fn nc(self, nc: u32) -> Self

Set the nonce count.

The first request using the same nonce value must start with nonce count 1 and increase by one for each subsequent request. The default value is 1.

pub fn cnonce<T>(self, cnonce: T) -> Self
where T: Into<String>,

Set the client nonce.

It will be generated automatically if not set.

pub fn echo_md5(self, echo_md5: bool) -> Self

Set this to false to omit the algorithm=MD5 parameter in the response.

This omits the parameter even if it was present in the challenge (it can be used to deal with some buggy servers). The default value is true.

pub fn build( self, method: &str, uri: &str, body: Option<&[u8]>, username: &str, password: &str, ) -> Result<DigestResponse, Error>

Build the Digest response.