pub struct DigestChallenge { /* private fields */ }Expand description
Digest challenge.
Implementations
Sourceimpl DigestChallenge
impl DigestChallenge
Sourcepub fn builder<T>(realm: T) -> DigestChallengeBuilder
pub fn builder<T>(realm: T) -> DigestChallengeBuilder
Get a Digest challenge builder for a given realm.
Sourcepub fn algorithm_param(&self) -> Option<&str>
pub fn algorithm_param(&self) -> Option<&str>
Get the algorithm parameter as sent in the challenge.
Sourcepub fn algorithm(&self) -> DigestAlgorithm
pub fn algorithm(&self) -> DigestAlgorithm
Get the actual digest algorithm.
Sourcepub fn qops(&self) -> &[QualityOfProtection]
pub fn qops(&self) -> &[QualityOfProtection]
Get the quality of protection values.
Sourcepub fn response_builder(&self) -> DigestResponseBuilder<'_>
pub fn response_builder(&self) -> DigestResponseBuilder<'_>
Get a Digest response builder for this challenge.